#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MAXEXPONENT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MAXEXPONENT_HPP_INCLUDED

#include <boost/simd/constant/include/constants/maxexponent.hpp>

#endif
